@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from dataclasses import dataclass
 from importlib import import_module
 from typing import Any, Type, cast
 
@@ -18,10 +19,12 @@ def get_rule(type_: str) -> Type[Rule[Any]]:
     raise NameError()
 
 
+@dataclass  # type: ignore
 class DoResolveRule(Rule[bool]):
     """The subtype of rule which determines if a market should resolve, returning a bool."""
 
 
+@dataclass  # type: ignore
 class ResolutionValueRule(Rule[AnyResolution]):
     """The subtype of rule which determines what a market should resolve to."""
 
